import 'option.dart';
import 'terminal.dart';

// Final values cannot be reassigned

// Marking Terminal class as constant because
// there is no data or instance variables associated 
// with the terminal class

// Private terminal '_'
final Terminal _terminal = const Terminal();

class Prompter {
  // Ask user a yes or no question and return selected option
  bool askBinary(String prompt) {
    final input = _ask('$prompt (y/n)', []);

    return input.contains('y');
  }
  // Ask user a multiple choice question and return selected option
  // OnError gets called on invalid input
  askMultiple(String prompt, List<Option> options) {
    final input = _ask(prompt, options);

    // Try to execute code within try{}
    // if throws an error execute code within catch{}
    try {
      return options[int.parse(input)].value;
    } catch (err) {
      return askMultiple(prompt, options);
    }
  }

  // Ask a question and return the user input
  String _ask(String prompt, List<Option> options) {
    _terminal.clearScreen();
    _terminal.printPrompt(prompt);
    _terminal.printOptions(options);

    return _terminal.collectInput();
  }
}
